"""Game-wide constants for item names and other shared values."""

HOUSE_KEY_1 = "THE HOUSE KEY 1"
HOUSE_KEY_2 = "THE HOUSE KEY 2"
HOUSE_KEY_3 = "THE HOUSE KEY 3"
STUDIO_KEY = "THE STUDIO KEY"
PASSEPARTOUT = "PASSEPARTOUT"
KNIFE = "KNIFE"
